/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.console.registry.command {


import com.adobe.cairngorm.commands.ICommand;
import com.adobe.cairngorm.control.CairngormEvent;
import com.adobe.cairngorm.control.CairngormEventDispatcher;

import mx.collections.ArrayCollection;
import mx.controls.Alert;
import mx.rpc.IResponder;
import mx.rpc.events.FaultEvent;
import mx.rpc.events.ResultEvent;

import org.ow2.easybeans.console.registry.event.RegistryInfoUpdatedEvent;
import org.ow2.easybeans.console.registry.model.RegistryModelLocator;

/**
 * Command used to get registry info
 * @author Florent Benoit
 */
public class GetRegistryInfoCommand implements ICommand, IResponder {

    private var model:RegistryModelLocator = Registry.getInstance().getModel();
    private var dispatcher:CairngormEventDispatcher = Registry.getInstance().getDispatcher();

    public function GetRegistryInfoCommand():void {}

    // -----------------------------------------------------------------
    // ICommand interface. (Cairngorm)
    // -----------------------------------------------------------------

    /**
     */
    public function execute( event : CairngormEvent ): void {
        model.getDelegate().responder = this;
        model.getDelegate().getRegistryInfo();
    }

    // -----------------------------------------------------------------
    // IResponder interface. (RPC)
    // -----------------------------------------------------------------

    /**
     * Manage the result found by a delegate.
     */
    public function result( event : Object ) : void {
        // value is contained in the event
        var resultEvent : ResultEvent = event as ResultEvent;
        var arrayCollection : ArrayCollection = resultEvent.result as ArrayCollection;
        model.registryInfo = arrayCollection;
        dispatcher.dispatchEvent( new RegistryInfoUpdatedEvent() );
    }


    /**
     * Manage failure.
     */
    public function fault( event : Object ) : void {
        var faultEvent : FaultEvent = FaultEvent( event );
        Alert.show( "Error while fetching data !" + faultEvent );
    }

}
}

